# Selenium

The primary integration point for Launchable is your team's build tool or test runner (i.e. whatever CLI you invoke to actually kick off your tests), not the test framework itself. Therefore, if you use the Selenium framework, check which tool you use to kick off your tests, such as:

* [Ant](../integrations/ant.md)
* [Gradle](../integrations/gradle.md)
* [Maven](../integrations/maven.md)
* [pytest](../integrations/pytest.md)

See each integration's page for instructions to add Launchable to your CI pipeline.
